
domDocument *  HTML_SimpleParseDocument ( char *html, int ignoreWhiteSpaces, 
                                          int forrest, domLength *pos,
                                          char **errStr );
